"""
Setup configuration for kubiya-control_plane_api package.

This file provides backward compatibility for tools that don't yet support pyproject.toml.
The actual package configuration is in pyproject.toml.
"""

from setuptools import setup

# Configuration is in pyproject.toml
# This file exists for backward compatibility
if __name__ == "__main__":
    setup()


